# Semi-Supervised Algorithms
=============
This project has the following algorithms:
- Co-Training
- Tri-Training
- Democratic Co-Learning
- Density Peaks
  - STDPNF


Release Notes
=============

See the commit logs at https://github.com/dpr1005/Semisupervised-learning-and-instance-selection-methods.